package com.landray.kmss.sys.attachment.controller;

import com.landray.kmss.common.dto.HttpRequestParameterWrapper;
import com.landray.kmss.common.rest.util.ControllerHelper;
import org.springframework.web.bind.annotation.RequestBody;
import com.landray.kmss.util.ResourceUtil;
import com.landray.kmss.sys.attachment.util.JgWebOffice;
import org.springframework.web.bind.annotation.ResponseBody;
import java.util.Map;
import com.landray.kmss.util.StringUtil;
import java.util.HashMap;
import com.landray.kmss.web.RestResponse;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletRequest;
import org.apache.commons.logging.LogFactory;
import org.apache.commons.logging.Log;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.stereotype.Controller;
import com.landray.kmss.common.rest.controller.BaseController;

@Controller
@RequestMapping({ "/data/sys-attachment/sysJgWebOffice" })
public class SysJgWebOfficeController extends BaseController
{
    protected final Log log;
    
    public SysJgWebOfficeController() {
        this.log = LogFactory.getLog(SysJgWebOfficeController.class);
    }
    
    @ResponseBody
    @RequestMapping({ "getJGSession" })
    public RestResponse<?> getJGSession(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        response.setHeader("Cache-Control", "no-cache");
        response.setHeader("Pragma", "no-cache");
        response.setDateHeader("Expires", -1L);
        final Map<String, String> sessionInfo = new HashMap<String, String>();
        sessionInfo.put("JSESSIONID", request.getSession().getId());
        final String cookieHeader = request.getHeader("Cookie");
        if (StringUtil.isNotNull(cookieHeader)) {
            final String[] cookies = cookieHeader.split(";");
            if (cookies != null) {
                for (int i = 0; i < cookies.length; ++i) {
                    final String cookie = cookies[i].trim();
                    sessionInfo.put(cookie.substring(0, cookie.indexOf("=")), cookie.substring(cookie.indexOf("=") + 1, cookie.length()));
                }
            }
        }
        return (RestResponse<?>)this.result(request, (Object)sessionInfo);
    }
    
    @ResponseBody
    @RequestMapping({ "getJGVersion" })
    public RestResponse<?> getJGVersion(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final Map<String, String> jgInfo = new HashMap<String, String>();
        final String JGBigVersion = JgWebOffice.getJGBigVersion();
        jgInfo.put("JGBigVersion", JGBigVersion);
        final String JGBigWebPDFVersion = JgWebOffice.getPDFBigVersion();
        jgInfo.put("JGBigWebPDFVersion", JGBigWebPDFVersion);
        final String osType = JgWebOffice.getOSType(request);
        jgInfo.put("osType", osType);
        String isEnabled = "false";
        final String isEnabledZZKK = JgWebOffice.getIsJGHandZzkkEnabled();
        if (isEnabledZZKK != null && "true".equals(isEnabledZZKK)) {
            isEnabled = "true";
        }
        jgInfo.put("isEnabled", isEnabled);
        final String jgPluginType = JgWebOffice.getJGPluginType();
        jgInfo.put("jgPluginType", jgPluginType);
        final String jgOfficeType = JgWebOffice.getJGOfficeType();
        jgInfo.put("jgOfficeType", jgOfficeType);
        return (RestResponse<?>)this.result(request, (Object)jgInfo);
    }
    
    @ResponseBody
    @RequestMapping({ "getJGOCXInfo" })
    public RestResponse<?> getJGOCXInfo(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final Map<String, String> jgInfo = new HashMap<String, String>();
        String clsid = ResourceUtil.getKmssConfigString("sys.att.jg.clsid");
        final String plugintype = ResourceUtil.getKmssConfigString("sys.att.jg.plugintype");
        if (StringUtil.isNull(clsid)) {
            clsid = "8B23EA28-2009-402F-92C4-59BE0E063499";
            if ("2003".equals(plugintype)) {
                clsid = "23739A7E-5741-4D1C-88D5-D50B18F7C347";
            }
        }
        jgInfo.put("clsid", clsid);
        final String JGBigVersion = JgWebOffice.getJGBigVersion();
        if ("windows".equals(JgWebOffice.getOSType(request))) {
            if (JGBigVersion != null && JGBigVersion.equals("2015")) {
                jgInfo.put("jgOcxUrl", JgWebOffice.getJGOcxURL2015());
                jgInfo.put("jgOcxVersion", JgWebOffice.getJGOcxVersion2015());
                jgInfo.put("jgOcxCopyright", JgWebOffice.getJGOcxCopyRight2015());
            }
        }
        else if (JgWebOffice.getIsJGHandZzkkEnabled() != null && "true".equals(JgWebOffice.getIsJGHandZzkkEnabled())) {
            jgInfo.put("jgOcxCopyright", JgWebOffice.getJGOcxCopyRightZZKK());
        }
        return (RestResponse<?>)this.result(request, (Object)jgInfo);
    }
    
    @RequestMapping({ "execute" })
    public void execute(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final JgWebOffice ws = new JgWebOffice();
        ws.execute(request, response);
    }
    
    @RequestMapping({ "executeAddition" })
    public void executeAddition(@RequestBody final Map<String, Object> vo, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final JgWebOffice ws = new JgWebOffice();
        final HttpRequestParameterWrapper reqWrapper = ControllerHelper.buildRequestParameterWrapper(request, (Map)vo);
        final String isAddition = reqWrapper.getParameter("_addition");
        if ("1".equals(isAddition)) {
            ws.addition((HttpServletRequest)reqWrapper, response);
        }
    }
}
